"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProvidersForConfig = exports.perPlatformHandlers = void 0;
const validate_token_1 = require("./validate-token");
const circleci = {
    discoveryUrlForToken: (config, token) => {
        // TODO: Pre-validate the token to claim this audience
        return `https://oidc.circleci.com/org/${config.organizationId}`;
    },
    validateToken: async (token, discoveryUrl) => {
        return await (0, validate_token_1.getValidatedToken)(token, discoveryUrl);
    },
    filterSecretProviders: async (config, claims) => {
        // Do a quick-pass to filter down secret providers based on contextId and projectId claims
        const projectId = claims['oidc.circleci.com/project-id'];
        // It is currently specified by CircleCI that this token will only ever have a single context ID
        // Ref: https://circleci.com/docs/openid-connect-tokens/#format-of-the-openid-connect-id-token
        // Due to a bug however the OIDC token may claim a "null" context-ids array, in that case
        // we assume 0 contexts to take the least-privilege approach
        let validatedContextIds = claims['oidc.circleci.com/context-ids'];
        if (validatedContextIds === null) {
            validatedContextIds = [];
        }
        const contextId = validatedContextIds[0];
        const filteredSecretProviders = config.secrets
            .filter((provider) => {
            if (!provider.filters.projectIds.includes(projectId))
                return false;
            // If the wildcard context is allowed then we don't need to check the contextIds filter
            if (!provider.filters.contextIds.includes('*')) {
                // If the contextId is missing from the claim don't validate it in case consumers
                // accidentally put `undefined` in the contextIds array
                if (!contextId || !provider.filters.contextIds.includes(contextId))
                    return false;
            }
            return true;
        })
            .map((p) => p.provider);
        return { subject: claims.sub, providers: filteredSecretProviders };
    },
};
const invalid = {
    discoveryUrlForToken: () => {
        return null;
    },
    validateToken: async () => {
        return null;
    },
    filterSecretProviders: async (_, claims) => {
        return { subject: claims.sub, providers: [] };
    },
};
exports.perPlatformHandlers = {
    circleci,
    invalid,
};
const getProvidersForConfig = async (logger, config, handler, token) => {
    const discoveryUrl = handler.discoveryUrlForToken(config, token);
    if (!discoveryUrl)
        return null;
    const claims = await handler.validateToken(token, discoveryUrl);
    if (!claims)
        return null;
    logger.info(`Validated incoming OIDC token from: ${claims.sub}`);
    return await handler.filterSecretProviders(config, claims);
};
exports.getProvidersForConfig = getProvidersForConfig;
//# sourceMappingURL=handlers.js.map